summaryrefslogtreecommitdiffstats
path: root/kexi/main/keximainwindowimpl.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2014-10-13 15:43:48 -0500
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2014-10-13 15:43:48 -0500
commitd504497c10d3cc9441a39245af1723e8c0ae556d (patch)
tree9fdf6ec3624b0c25e04b5bc37c96ecef0fdaca18 /kexi/main/keximainwindowimpl.cpp
parentc128ab57b3b5f3a57427a78cef7d5d4236cc9822 (diff)
downloadkoffice-d504497c10d3cc9441a39245af1723e8c0ae556d.tar.gz
koffice-d504497c10d3cc9441a39245af1723e8c0ae556d.zip
Bring filenew, fileopen, fileprint, filequickprint, filesave, filesaveas, fileclose, editclear, editcopy, editcut, editdelete, editpaste, folder_new, and gohome icons into XDG compliance
Diffstat (limited to 'kexi/main/keximainwindowimpl.cpp')
-rw-r--r--kexi/main/keximainwindowimpl.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/kexi/main/keximainwindowimpl.cpp b/kexi/main/keximainwindowimpl.cpp
index 69ac854b..1201a79c 100644
--- a/kexi/main/keximainwindowimpl.cpp
+++ b/kexi/main/keximainwindowimpl.cpp
@@ -524,7 +524,7 @@ void KexiMainWindowImpl::initActions()
// connect(d->actionMapper, TQT_SIGNAL(mapped(const TQString &)), TQT_TQOBJECT(this), TQT_SLOT(slotAction(const TQString &)));
// PROJECT MENU
- TDEAction *action = new TDEAction(i18n("&New..."), "filenew", TDEStdAccel::shortcut(TDEStdAccel::New),
+ TDEAction *action = new TDEAction(i18n("&New..."), "document-new", TDEStdAccel::shortcut(TDEStdAccel::New),
TQT_TQOBJECT(this), TQT_SLOT(slotProjectNew()), actionCollection(), "project_new");
action->setToolTip(i18n("Create a new project"));
action->setWhatsThis(i18n("Creates a new project. Currently opened project is not affected."));
@@ -563,13 +563,13 @@ void KexiMainWindowImpl::initActions()
d->action_save = KStdAction::save(
TQT_TQOBJECT(this), TQT_SLOT( slotProjectSave() ), actionCollection(), "project_save" );
-// d->action_save = new TDEAction(i18n("&Save"), "filesave", TDEStdAccel::shortcut(TDEStdAccel::Save),
+// d->action_save = new TDEAction(i18n("&Save"), "document-save", TDEStdAccel::shortcut(TDEStdAccel::Save),
// TQT_TQOBJECT(this), TQT_SLOT(slotProjectSave()), actionCollection(), "project_save");
d->action_save->setToolTip(i18n("Save object changes"));
d->action_save->setWhatsThis(i18n("Saves object changes from currently selected window."));
#ifdef KEXI_SHOW_UNIMPLEMENTED
- d->action_save_as = new TDEAction(i18n("Save &As..."), "filesaveas", 0,
+ d->action_save_as = new TDEAction(i18n("Save &As..."), "document-save-as", 0,
TQT_TQOBJECT(this), TQT_SLOT(slotProjectSaveAs()), actionCollection(), "project_saveas");
d->action_save_as->setToolTip(i18n("Save object as"));
d->action_save_as->setWhatsThis(
@@ -582,7 +582,7 @@ void KexiMainWindowImpl::initActions()
d->action_project_properties = d->dummy_action;
#endif
- d->action_close = new TDEAction(i18n("&Close Project"), "fileclose", 0,
+ d->action_close = new TDEAction(i18n("&Close Project"), "window-close", 0,
TQT_TQOBJECT(this), TQT_SLOT(slotProjectClose()), actionCollection(), "project_close" );
d->action_close->setToolTip(i18n("Close the current project"));
d->action_close->setWhatsThis(i18n("Closes the current project."));
@@ -633,7 +633,7 @@ void KexiMainWindowImpl::initActions()
d->action_project_export_data_table->setWhatsThis(
i18n("Exports data from the active table or query data to a file."));
//TODO new TDEAction(i18n("From File..."), "fileopen", 0,
//TODO TQT_TQOBJECT(this), TQT_SLOT(slotImportFile()), actionCollection(), "project_import_file");
//TODO new TDEAction(i18n("From Server..."), "server", 0,
//TODO TQT_TQOBJECT(this), TQT_SLOT(slotImportServer()), actionCollection(), "project_import_server");
@@ -715,7 +715,7 @@ void KexiMainWindowImpl::initActions()
d->action_edit_select_all = createSharedAction( KStdAction::SelectAll, "edit_select_all");
- d->action_edit_delete = createSharedAction(i18n("&Delete"), "editdelete",
+ d->action_edit_delete = createSharedAction(i18n("&Delete"), "edit-delete",
0/*TQt::Key_Delete*/, "edit_delete");
d->action_edit_delete->setToolTip(i18n("Delete selected object"));
d->action_edit_delete->setWhatsThis(i18n("Deletes currently selected object."));
@@ -3791,7 +3791,7 @@ tristate KexiMainWindowImpl::removeObject( KexiPart::Item *item, bool dontAsk )
"%1\n"
"If you click \"Delete\", you will not be able to undo the deletion.")
.arg( "</p><p>"+part->instanceCaption()+" \""+ item->name() + "\"?</p>" ),
- 0, KGuiItem(i18n("Delete"), "editdelete"), KStdGuiItem::no()))
+ 0, KGuiItem(i18n("Delete"), "edit-delete"), KStdGuiItem::no()))
return cancelled;
}
@@ -633,7 +633,7 @@ void KexiMainWindowImpl::initActions()
d->action_project_export_data_table->setWhatsThis(
i18n("Exports data from the active table or query data to a file."));
-//TODO new TDEAction(i18n("From File..."), "fileopen", 0,
+//TODO new TDEAction(i18n("From File..."), "document-open", 0,
//TODO TQT_TQOBJECT(this), TQT_SLOT(slotImportFile()), actionCollection(), "project_import_file");
//TODO new TDEAction(i18n("From Server..."), "server", 0,